# This file is auto-generated by hatch-gradle-version. Do not edit.

GRADLE_VERSION = "1.4.0"
FULL_VERSION = "1.4.0.1.0.0"

ARCHIVES_BASE_NAME = "hexical"
FABRIC_API_VERSION = "0.77.0+1.19.2"
FABRIC_KOTLIN_VERSION = "1.9.0+kotlin.1.8.0"
HEXCASTING_VERSION = "0.10.3"
KOTLIN_STDLIB_DEFAULT_DEPENDENCY = "false"
LOADER_VERSION = "0.15.11"
MAVEN_GROUP = "miyucomics.hexical"
MINECRAFT_VERSION = "1.19.2"
MIXIN_EXTRAS_VERSION = "0.4.0"
MOD_VERSION = "1.4.0"
ORG_GRADLE_JVMARGS = "-Xmx1G"
ORG_GRADLE_PARALLEL = "true"
PATCHOULI_VERSION = "77"
PAUCAL_VERSION = "0.5.0"
PLAYER_ANIMATOR_VERSION = "1.0.2"
YARN_MAPPINGS = "1.19.2+build.28:v2"
